def convert_enumeration_name_to_normalized_text(enumeration_name):
    return enumeration_name.replace('_', ' ').title()

def convert_formatted_enumerations_back_to_integer_values(enumeration, enum_value):
    return enumeration(enum_value.replace(' ', '_').lower()).value

def get_dict_key_from_value(source_dict, value_to_find):
    for key, value in source_dict.items():
        if value_to_find.lower() == value.lower():
            return key
    raise Exception('Key: {}, not found in dict: {}'.format(value_to_find, source_dict))

